# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['NatGatewayArgs', 'NatGateway']

@pulumi.input_type
class NatGatewayArgs:
    def __init__(__self__, *,
                 ens_region_id: pulumi.Input[str],
                 network_id: pulumi.Input[str],
                 vswitch_id: pulumi.Input[str],
                 instance_type: Optional[pulumi.Input[str]] = None,
                 nat_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a NatGateway resource.
        :param pulumi.Input[str] ens_region_id: The ID of the ENS node.
        :param pulumi.Input[str] network_id: The network ID.
        :param pulumi.Input[str] vswitch_id: The vSwitch ID.
        :param pulumi.Input[str] instance_type: NAT specifications. Value: `enat.default`.
        :param pulumi.Input[str] nat_name: The name of the NAT gateway. The length is 1 to 128 characters, but it cannot start with 'http:// 'or 'https.
        """
        pulumi.set(__self__, "ens_region_id", ens_region_id)
        pulumi.set(__self__, "network_id", network_id)
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if nat_name is not None:
            pulumi.set(__self__, "nat_name", nat_name)

    @property
    @pulumi.getter(name="ensRegionId")
    def ens_region_id(self) -> pulumi.Input[str]:
        """
        The ID of the ENS node.
        """
        return pulumi.get(self, "ens_region_id")

    @ens_region_id.setter
    def ens_region_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "ens_region_id", value)

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> pulumi.Input[str]:
        """
        The network ID.
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "network_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Input[str]:
        """
        The vSwitch ID.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vswitch_id", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[str]]:
        """
        NAT specifications. Value: `enat.default`.
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="natName")
    def nat_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the NAT gateway. The length is 1 to 128 characters, but it cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "nat_name")

    @nat_name.setter
    def nat_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nat_name", value)


@pulumi.input_type
class _NatGatewayState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 ens_region_id: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 nat_name: Optional[pulumi.Input[str]] = None,
                 network_id: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering NatGateway resources.
        :param pulumi.Input[str] create_time: Creation time. UTC time, in the format of YYYY-MM-DDThh:mm:ssZ.
        :param pulumi.Input[str] ens_region_id: The ID of the ENS node.
        :param pulumi.Input[str] instance_type: NAT specifications. Value: `enat.default`.
        :param pulumi.Input[str] nat_name: The name of the NAT gateway. The length is 1 to 128 characters, but it cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] network_id: The network ID.
        :param pulumi.Input[str] vswitch_id: The vSwitch ID.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if ens_region_id is not None:
            pulumi.set(__self__, "ens_region_id", ens_region_id)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if nat_name is not None:
            pulumi.set(__self__, "nat_name", nat_name)
        if network_id is not None:
            pulumi.set(__self__, "network_id", network_id)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        Creation time. UTC time, in the format of YYYY-MM-DDThh:mm:ssZ.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="ensRegionId")
    def ens_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the ENS node.
        """
        return pulumi.get(self, "ens_region_id")

    @ens_region_id.setter
    def ens_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ens_region_id", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[str]]:
        """
        NAT specifications. Value: `enat.default`.
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="natName")
    def nat_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the NAT gateway. The length is 1 to 128 characters, but it cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "nat_name")

    @nat_name.setter
    def nat_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nat_name", value)

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> Optional[pulumi.Input[str]]:
        """
        The network ID.
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[str]]:
        """
        The vSwitch ID.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_id", value)


class NatGateway(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ens_region_id: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 nat_name: Optional[pulumi.Input[str]] = None,
                 network_id: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Ens Nat Gateway resource.

        Nat gateway of ENS.

        For information about Ens Nat Gateway and how to use it, see [What is Nat Gateway](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.227.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        ens_region_id = config.get("ensRegionId")
        if ens_region_id is None:
            ens_region_id = "cn-chenzhou-telecom_unicom_cmcc"
        default_obbr_l7 = alicloud.ens.Network("defaultObbrL7",
            network_name=name,
            description=name,
            cidr_block="10.0.0.0/8",
            ens_region_id=ens_region_id)
        defaulte_fw783 = alicloud.ens.Vswitch("defaulteFw783",
            cidr_block="10.0.8.0/24",
            vswitch_name=name,
            ens_region_id=default_obbr_l7.ens_region_id,
            network_id=default_obbr_l7.id)
        default = alicloud.ens.NatGateway("default",
            vswitch_id=defaulte_fw783.id,
            ens_region_id=defaulte_fw783.ens_region_id,
            network_id=defaulte_fw783.network_id,
            instance_type="enat.default",
            nat_name=name)
        ```

        ## Import

        Ens Nat Gateway can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ens/natGateway:NatGateway example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] ens_region_id: The ID of the ENS node.
        :param pulumi.Input[str] instance_type: NAT specifications. Value: `enat.default`.
        :param pulumi.Input[str] nat_name: The name of the NAT gateway. The length is 1 to 128 characters, but it cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] network_id: The network ID.
        :param pulumi.Input[str] vswitch_id: The vSwitch ID.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NatGatewayArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Ens Nat Gateway resource.

        Nat gateway of ENS.

        For information about Ens Nat Gateway and how to use it, see [What is Nat Gateway](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.227.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        ens_region_id = config.get("ensRegionId")
        if ens_region_id is None:
            ens_region_id = "cn-chenzhou-telecom_unicom_cmcc"
        default_obbr_l7 = alicloud.ens.Network("defaultObbrL7",
            network_name=name,
            description=name,
            cidr_block="10.0.0.0/8",
            ens_region_id=ens_region_id)
        defaulte_fw783 = alicloud.ens.Vswitch("defaulteFw783",
            cidr_block="10.0.8.0/24",
            vswitch_name=name,
            ens_region_id=default_obbr_l7.ens_region_id,
            network_id=default_obbr_l7.id)
        default = alicloud.ens.NatGateway("default",
            vswitch_id=defaulte_fw783.id,
            ens_region_id=defaulte_fw783.ens_region_id,
            network_id=defaulte_fw783.network_id,
            instance_type="enat.default",
            nat_name=name)
        ```

        ## Import

        Ens Nat Gateway can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ens/natGateway:NatGateway example <id>
        ```

        :param str resource_name: The name of the resource.
        :param NatGatewayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NatGatewayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ens_region_id: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 nat_name: Optional[pulumi.Input[str]] = None,
                 network_id: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NatGatewayArgs.__new__(NatGatewayArgs)

            if ens_region_id is None and not opts.urn:
                raise TypeError("Missing required property 'ens_region_id'")
            __props__.__dict__["ens_region_id"] = ens_region_id
            __props__.__dict__["instance_type"] = instance_type
            __props__.__dict__["nat_name"] = nat_name
            if network_id is None and not opts.urn:
                raise TypeError("Missing required property 'network_id'")
            __props__.__dict__["network_id"] = network_id
            if vswitch_id is None and not opts.urn:
                raise TypeError("Missing required property 'vswitch_id'")
            __props__.__dict__["vswitch_id"] = vswitch_id
            __props__.__dict__["create_time"] = None
        super(NatGateway, __self__).__init__(
            'alicloud:ens/natGateway:NatGateway',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            ens_region_id: Optional[pulumi.Input[str]] = None,
            instance_type: Optional[pulumi.Input[str]] = None,
            nat_name: Optional[pulumi.Input[str]] = None,
            network_id: Optional[pulumi.Input[str]] = None,
            vswitch_id: Optional[pulumi.Input[str]] = None) -> 'NatGateway':
        """
        Get an existing NatGateway resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: Creation time. UTC time, in the format of YYYY-MM-DDThh:mm:ssZ.
        :param pulumi.Input[str] ens_region_id: The ID of the ENS node.
        :param pulumi.Input[str] instance_type: NAT specifications. Value: `enat.default`.
        :param pulumi.Input[str] nat_name: The name of the NAT gateway. The length is 1 to 128 characters, but it cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] network_id: The network ID.
        :param pulumi.Input[str] vswitch_id: The vSwitch ID.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NatGatewayState.__new__(_NatGatewayState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["ens_region_id"] = ens_region_id
        __props__.__dict__["instance_type"] = instance_type
        __props__.__dict__["nat_name"] = nat_name
        __props__.__dict__["network_id"] = network_id
        __props__.__dict__["vswitch_id"] = vswitch_id
        return NatGateway(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        Creation time. UTC time, in the format of YYYY-MM-DDThh:mm:ssZ.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="ensRegionId")
    def ens_region_id(self) -> pulumi.Output[str]:
        """
        The ID of the ENS node.
        """
        return pulumi.get(self, "ens_region_id")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output[str]:
        """
        NAT specifications. Value: `enat.default`.
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="natName")
    def nat_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the NAT gateway. The length is 1 to 128 characters, but it cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "nat_name")

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> pulumi.Output[str]:
        """
        The network ID.
        """
        return pulumi.get(self, "network_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Output[str]:
        """
        The vSwitch ID.
        """
        return pulumi.get(self, "vswitch_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MetricRuleTemplateArgs', 'MetricRuleTemplate']

@pulumi.input_type
class MetricRuleTemplateArgs:
    def __init__(__self__, *,
                 metric_rule_template_name: pulumi.Input[str],
                 alert_templates: Optional[pulumi.Input[Sequence[pulumi.Input['MetricRuleTemplateAlertTemplateArgs']]]] = None,
                 apply_mode: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enable_end_time: Optional[pulumi.Input[str]] = None,
                 enable_start_time: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 notify_level: Optional[pulumi.Input[str]] = None,
                 silence_time: Optional[pulumi.Input[int]] = None,
                 webhook: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a MetricRuleTemplate resource.
        :param pulumi.Input[str] metric_rule_template_name: The name of the alert template.
        :param pulumi.Input[Sequence[pulumi.Input['MetricRuleTemplateAlertTemplateArgs']]] alert_templates: The details of alert rules that are generated based on the alert template. See `alert_templates` below.
        :param pulumi.Input[str] apply_mode: The mode in which the alert template is applied. Valid values:
               - `GROUP_INSTANCE_FIRST`: The metrics in the application group take precedence.
               - `ALARM_TEMPLATE_FIRST `: The metrics specified in the alert template take precedence.
        :param pulumi.Input[str] description: The description of the alert template.
        :param pulumi.Input[str] enable_end_time: The end of the time period during which the alert rule is effective. Valid values: `00` to `23`. The value `00` indicates 00:59 and the value `23` indicates 23:59.
        :param pulumi.Input[str] enable_start_time: The beginning of the time period during which the alert rule is effective. Valid values: `00` to `23`. The value `00` indicates 00:00 and the value `23` indicates 23:00.
        :param pulumi.Input[str] group_id: The ID of the application group.
        :param pulumi.Input[str] notify_level: The alert notification method. Valid values:
        :param pulumi.Input[int] silence_time: The mute period during which notifications are not repeatedly sent for an alert. Unit: seconds. Default value: `86400`. Valid values: `0` to `86400`.
        :param pulumi.Input[str] webhook: The callback URL to which a POST request is sent when an alert is triggered based on the alert rule.
        """
        pulumi.set(__self__, "metric_rule_template_name", metric_rule_template_name)
        if alert_templates is not None:
            pulumi.set(__self__, "alert_templates", alert_templates)
        if apply_mode is not None:
            pulumi.set(__self__, "apply_mode", apply_mode)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_end_time is not None:
            pulumi.set(__self__, "enable_end_time", enable_end_time)
        if enable_start_time is not None:
            pulumi.set(__self__, "enable_start_time", enable_start_time)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if notify_level is not None:
            pulumi.set(__self__, "notify_level", notify_level)
        if silence_time is not None:
            pulumi.set(__self__, "silence_time", silence_time)
        if webhook is not None:
            pulumi.set(__self__, "webhook", webhook)

    @property
    @pulumi.getter(name="metricRuleTemplateName")
    def metric_rule_template_name(self) -> pulumi.Input[str]:
        """
        The name of the alert template.
        """
        return pulumi.get(self, "metric_rule_template_name")

    @metric_rule_template_name.setter
    def metric_rule_template_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "metric_rule_template_name", value)

    @property
    @pulumi.getter(name="alertTemplates")
    def alert_templates(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MetricRuleTemplateAlertTemplateArgs']]]]:
        """
        The details of alert rules that are generated based on the alert template. See `alert_templates` below.
        """
        return pulumi.get(self, "alert_templates")

    @alert_templates.setter
    def alert_templates(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MetricRuleTemplateAlertTemplateArgs']]]]):
        pulumi.set(self, "alert_templates", value)

    @property
    @pulumi.getter(name="applyMode")
    def apply_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The mode in which the alert template is applied. Valid values:
        - `GROUP_INSTANCE_FIRST`: The metrics in the application group take precedence.
        - `ALARM_TEMPLATE_FIRST `: The metrics specified in the alert template take precedence.
        """
        return pulumi.get(self, "apply_mode")

    @apply_mode.setter
    def apply_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "apply_mode", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the alert template.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableEndTime")
    def enable_end_time(self) -> Optional[pulumi.Input[str]]:
        """
        The end of the time period during which the alert rule is effective. Valid values: `00` to `23`. The value `00` indicates 00:59 and the value `23` indicates 23:59.
        """
        return pulumi.get(self, "enable_end_time")

    @enable_end_time.setter
    def enable_end_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "enable_end_time", value)

    @property
    @pulumi.getter(name="enableStartTime")
    def enable_start_time(self) -> Optional[pulumi.Input[str]]:
        """
        The beginning of the time period during which the alert rule is effective. Valid values: `00` to `23`. The value `00` indicates 00:00 and the value `23` indicates 23:00.
        """
        return pulumi.get(self, "enable_start_time")

    @enable_start_time.setter
    def enable_start_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "enable_start_time", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the application group.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="notifyLevel")
    def notify_level(self) -> Optional[pulumi.Input[str]]:
        """
        The alert notification method. Valid values:
        """
        return pulumi.get(self, "notify_level")

    @notify_level.setter
    def notify_level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notify_level", value)

    @property
    @pulumi.getter(name="silenceTime")
    def silence_time(self) -> Optional[pulumi.Input[int]]:
        """
        The mute period during which notifications are not repeatedly sent for an alert. Unit: seconds. Default value: `86400`. Valid values: `0` to `86400`.
        """
        return pulumi.get(self, "silence_time")

    @silence_time.setter
    def silence_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "silence_time", value)

    @property
    @pulumi.getter
    def webhook(self) -> Optional[pulumi.Input[str]]:
        """
        The callback URL to which a POST request is sent when an alert is triggered based on the alert rule.
        """
        return pulumi.get(self, "webhook")

    @webhook.setter
    def webhook(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "webhook", value)


@pulumi.input_type
class _MetricRuleTemplateState:
    def __init__(__self__, *,
                 alert_templates: Optional[pulumi.Input[Sequence[pulumi.Input['MetricRuleTemplateAlertTemplateArgs']]]] = None,
                 apply_mode: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enable_end_time: Optional[pulumi.Input[str]] = None,
                 enable_start_time: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 metric_rule_template_name: Optional[pulumi.Input[str]] = None,
                 notify_level: Optional[pulumi.Input[str]] = None,
                 rest_version: Optional[pulumi.Input[str]] = None,
                 silence_time: Optional[pulumi.Input[int]] = None,
                 webhook: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering MetricRuleTemplate resources.
        :param pulumi.Input[Sequence[pulumi.Input['MetricRuleTemplateAlertTemplateArgs']]] alert_templates: The details of alert rules that are generated based on the alert template. See `alert_templates` below.
        :param pulumi.Input[str] apply_mode: The mode in which the alert template is applied. Valid values:
               - `GROUP_INSTANCE_FIRST`: The metrics in the application group take precedence.
               - `ALARM_TEMPLATE_FIRST `: The metrics specified in the alert template take precedence.
        :param pulumi.Input[str] description: The description of the alert template.
        :param pulumi.Input[str] enable_end_time: The end of the time period during which the alert rule is effective. Valid values: `00` to `23`. The value `00` indicates 00:59 and the value `23` indicates 23:59.
        :param pulumi.Input[str] enable_start_time: The beginning of the time period during which the alert rule is effective. Valid values: `00` to `23`. The value `00` indicates 00:00 and the value `23` indicates 23:00.
        :param pulumi.Input[str] group_id: The ID of the application group.
        :param pulumi.Input[str] metric_rule_template_name: The name of the alert template.
        :param pulumi.Input[str] notify_level: The alert notification method. Valid values:
        :param pulumi.Input[str] rest_version: The version of the alert template.
        :param pulumi.Input[int] silence_time: The mute period during which notifications are not repeatedly sent for an alert. Unit: seconds. Default value: `86400`. Valid values: `0` to `86400`.
        :param pulumi.Input[str] webhook: The callback URL to which a POST request is sent when an alert is triggered based on the alert rule.
        """
        if alert_templates is not None:
            pulumi.set(__self__, "alert_templates", alert_templates)
        if apply_mode is not None:
            pulumi.set(__self__, "apply_mode", apply_mode)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_end_time is not None:
            pulumi.set(__self__, "enable_end_time", enable_end_time)
        if enable_start_time is not None:
            pulumi.set(__self__, "enable_start_time", enable_start_time)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if metric_rule_template_name is not None:
            pulumi.set(__self__, "metric_rule_template_name", metric_rule_template_name)
        if notify_level is not None:
            pulumi.set(__self__, "notify_level", notify_level)
        if rest_version is not None:
            pulumi.set(__self__, "rest_version", rest_version)
        if silence_time is not None:
            pulumi.set(__self__, "silence_time", silence_time)
        if webhook is not None:
            pulumi.set(__self__, "webhook", webhook)

    @property
    @pulumi.getter(name="alertTemplates")
    def alert_templates(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MetricRuleTemplateAlertTemplateArgs']]]]:
        """
        The details of alert rules that are generated based on the alert template. See `alert_templates` below.
        """
        return pulumi.get(self, "alert_templates")

    @alert_templates.setter
    def alert_templates(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MetricRuleTemplateAlertTemplateArgs']]]]):
        pulumi.set(self, "alert_templates", value)

    @property
    @pulumi.getter(name="applyMode")
    def apply_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The mode in which the alert template is applied. Valid values:
        - `GROUP_INSTANCE_FIRST`: The metrics in the application group take precedence.
        - `ALARM_TEMPLATE_FIRST `: The metrics specified in the alert template take precedence.
        """
        return pulumi.get(self, "apply_mode")

    @apply_mode.setter
    def apply_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "apply_mode", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the alert template.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableEndTime")
    def enable_end_time(self) -> Optional[pulumi.Input[str]]:
        """
        The end of the time period during which the alert rule is effective. Valid values: `00` to `23`. The value `00` indicates 00:59 and the value `23` indicates 23:59.
        """
        return pulumi.get(self, "enable_end_time")

    @enable_end_time.setter
    def enable_end_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "enable_end_time", value)

    @property
    @pulumi.getter(name="enableStartTime")
    def enable_start_time(self) -> Optional[pulumi.Input[str]]:
        """
        The beginning of the time period during which the alert rule is effective. Valid values: `00` to `23`. The value `00` indicates 00:00 and the value `23` indicates 23:00.
        """
        return pulumi.get(self, "enable_start_time")

    @enable_start_time.setter
    def enable_start_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "enable_start_time", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the application group.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="metricRuleTemplateName")
    def metric_rule_template_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the alert template.
        """
        return pulumi.get(self, "metric_rule_template_name")

    @metric_rule_template_name.setter
    def metric_rule_template_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "metric_rule_template_name", value)

    @property
    @pulumi.getter(name="notifyLevel")
    def notify_level(self) -> Optional[pulumi.Input[str]]:
        """
        The alert notification method. Valid values:
        """
        return pulumi.get(self, "notify_level")

    @notify_level.setter
    def notify_level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notify_level", value)

    @property
    @pulumi.getter(name="restVersion")
    def rest_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of the alert template.
        """
        return pulumi.get(self, "rest_version")

    @rest_version.setter
    def rest_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rest_version", value)

    @property
    @pulumi.getter(name="silenceTime")
    def silence_time(self) -> Optional[pulumi.Input[int]]:
        """
        The mute period during which notifications are not repeatedly sent for an alert. Unit: seconds. Default value: `86400`. Valid values: `0` to `86400`.
        """
        return pulumi.get(self, "silence_time")

    @silence_time.setter
    def silence_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "silence_time", value)

    @property
    @pulumi.getter
    def webhook(self) -> Optional[pulumi.Input[str]]:
        """
        The callback URL to which a POST request is sent when an alert is triggered based on the alert rule.
        """
        return pulumi.get(self, "webhook")

    @webhook.setter
    def webhook(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "webhook", value)


class MetricRuleTemplate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alert_templates: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MetricRuleTemplateAlertTemplateArgs', 'MetricRuleTemplateAlertTemplateArgsDict']]]]] = None,
                 apply_mode: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enable_end_time: Optional[pulumi.Input[str]] = None,
                 enable_start_time: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 metric_rule_template_name: Optional[pulumi.Input[str]] = None,
                 notify_level: Optional[pulumi.Input[str]] = None,
                 silence_time: Optional[pulumi.Input[int]] = None,
                 webhook: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Cloud Monitor Service Metric Rule Template resource.

        For information about Cloud Monitor Service Metric Rule Template and how to use it, see [What is Metric Rule Template](https://www.alibabacloud.com/help/en/cloudmonitor/latest/createmetricruletemplate).

        > **NOTE:** Available since v1.134.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        example = alicloud.cms.MetricRuleTemplate("example",
            metric_rule_template_name=name,
            alert_templates=[{
                "category": "ecs",
                "metric_name": "cpu_total",
                "namespace": "acs_ecs_dashboard",
                "rule_name": "tf_example",
                "escalations": {
                    "critical": {
                        "comparison_operator": "GreaterThanThreshold",
                        "statistics": "Average",
                        "threshold": "90",
                        "times": "3",
                    },
                },
            }])
        ```

        ## Import

        Cloud Monitor Service Metric Rule Template can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cms/metricRuleTemplate:MetricRuleTemplate example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['MetricRuleTemplateAlertTemplateArgs', 'MetricRuleTemplateAlertTemplateArgsDict']]]] alert_templates: The details of alert rules that are generated based on the alert template. See `alert_templates` below.
        :param pulumi.Input[str] apply_mode: The mode in which the alert template is applied. Valid values:
               - `GROUP_INSTANCE_FIRST`: The metrics in the application group take precedence.
               - `ALARM_TEMPLATE_FIRST `: The metrics specified in the alert template take precedence.
        :param pulumi.Input[str] description: The description of the alert template.
        :param pulumi.Input[str] enable_end_time: The end of the time period during which the alert rule is effective. Valid values: `00` to `23`. The value `00` indicates 00:59 and the value `23` indicates 23:59.
        :param pulumi.Input[str] enable_start_time: The beginning of the time period during which the alert rule is effective. Valid values: `00` to `23`. The value `00` indicates 00:00 and the value `23` indicates 23:00.
        :param pulumi.Input[str] group_id: The ID of the application group.
        :param pulumi.Input[str] metric_rule_template_name: The name of the alert template.
        :param pulumi.Input[str] notify_level: The alert notification method. Valid values:
        :param pulumi.Input[int] silence_time: The mute period during which notifications are not repeatedly sent for an alert. Unit: seconds. Default value: `86400`. Valid values: `0` to `86400`.
        :param pulumi.Input[str] webhook: The callback URL to which a POST request is sent when an alert is triggered based on the alert rule.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MetricRuleTemplateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Monitor Service Metric Rule Template resource.

        For information about Cloud Monitor Service Metric Rule Template and how to use it, see [What is Metric Rule Template](https://www.alibabacloud.com/help/en/cloudmonitor/latest/createmetricruletemplate).

        > **NOTE:** Available since v1.134.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        example = alicloud.cms.MetricRuleTemplate("example",
            metric_rule_template_name=name,
            alert_templates=[{
                "category": "ecs",
                "metric_name": "cpu_total",
                "namespace": "acs_ecs_dashboard",
                "rule_name": "tf_example",
                "escalations": {
                    "critical": {
                        "comparison_operator": "GreaterThanThreshold",
                        "statistics": "Average",
                        "threshold": "90",
                        "times": "3",
                    },
                },
            }])
        ```

        ## Import

        Cloud Monitor Service Metric Rule Template can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cms/metricRuleTemplate:MetricRuleTemplate example <id>
        ```

        :param str resource_name: The name of the resource.
        :param MetricRuleTemplateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MetricRuleTemplateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alert_templates: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MetricRuleTemplateAlertTemplateArgs', 'MetricRuleTemplateAlertTemplateArgsDict']]]]] = None,
                 apply_mode: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enable_end_time: Optional[pulumi.Input[str]] = None,
                 enable_start_time: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 metric_rule_template_name: Optional[pulumi.Input[str]] = None,
                 notify_level: Optional[pulumi.Input[str]] = None,
                 silence_time: Optional[pulumi.Input[int]] = None,
                 webhook: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MetricRuleTemplateArgs.__new__(MetricRuleTemplateArgs)

            __props__.__dict__["alert_templates"] = alert_templates
            __props__.__dict__["apply_mode"] = apply_mode
            __props__.__dict__["description"] = description
            __props__.__dict__["enable_end_time"] = enable_end_time
            __props__.__dict__["enable_start_time"] = enable_start_time
            __props__.__dict__["group_id"] = group_id
            if metric_rule_template_name is None and not opts.urn:
                raise TypeError("Missing required property 'metric_rule_template_name'")
            __props__.__dict__["metric_rule_template_name"] = metric_rule_template_name
            __props__.__dict__["notify_level"] = notify_level
            __props__.__dict__["silence_time"] = silence_time
            __props__.__dict__["webhook"] = webhook
            __props__.__dict__["rest_version"] = None
        super(MetricRuleTemplate, __self__).__init__(
            'alicloud:cms/metricRuleTemplate:MetricRuleTemplate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alert_templates: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MetricRuleTemplateAlertTemplateArgs', 'MetricRuleTemplateAlertTemplateArgsDict']]]]] = None,
            apply_mode: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            enable_end_time: Optional[pulumi.Input[str]] = None,
            enable_start_time: Optional[pulumi.Input[str]] = None,
            group_id: Optional[pulumi.Input[str]] = None,
            metric_rule_template_name: Optional[pulumi.Input[str]] = None,
            notify_level: Optional[pulumi.Input[str]] = None,
            rest_version: Optional[pulumi.Input[str]] = None,
            silence_time: Optional[pulumi.Input[int]] = None,
            webhook: Optional[pulumi.Input[str]] = None) -> 'MetricRuleTemplate':
        """
        Get an existing MetricRuleTemplate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['MetricRuleTemplateAlertTemplateArgs', 'MetricRuleTemplateAlertTemplateArgsDict']]]] alert_templates: The details of alert rules that are generated based on the alert template. See `alert_templates` below.
        :param pulumi.Input[str] apply_mode: The mode in which the alert template is applied. Valid values:
               - `GROUP_INSTANCE_FIRST`: The metrics in the application group take precedence.
               - `ALARM_TEMPLATE_FIRST `: The metrics specified in the alert template take precedence.
        :param pulumi.Input[str] description: The description of the alert template.
        :param pulumi.Input[str] enable_end_time: The end of the time period during which the alert rule is effective. Valid values: `00` to `23`. The value `00` indicates 00:59 and the value `23` indicates 23:59.
        :param pulumi.Input[str] enable_start_time: The beginning of the time period during which the alert rule is effective. Valid values: `00` to `23`. The value `00` indicates 00:00 and the value `23` indicates 23:00.
        :param pulumi.Input[str] group_id: The ID of the application group.
        :param pulumi.Input[str] metric_rule_template_name: The name of the alert template.
        :param pulumi.Input[str] notify_level: The alert notification method. Valid values:
        :param pulumi.Input[str] rest_version: The version of the alert template.
        :param pulumi.Input[int] silence_time: The mute period during which notifications are not repeatedly sent for an alert. Unit: seconds. Default value: `86400`. Valid values: `0` to `86400`.
        :param pulumi.Input[str] webhook: The callback URL to which a POST request is sent when an alert is triggered based on the alert rule.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MetricRuleTemplateState.__new__(_MetricRuleTemplateState)

        __props__.__dict__["alert_templates"] = alert_templates
        __props__.__dict__["apply_mode"] = apply_mode
        __props__.__dict__["description"] = description
        __props__.__dict__["enable_end_time"] = enable_end_time
        __props__.__dict__["enable_start_time"] = enable_start_time
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["metric_rule_template_name"] = metric_rule_template_name
        __props__.__dict__["notify_level"] = notify_level
        __props__.__dict__["rest_version"] = rest_version
        __props__.__dict__["silence_time"] = silence_time
        __props__.__dict__["webhook"] = webhook
        return MetricRuleTemplate(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="alertTemplates")
    def alert_templates(self) -> pulumi.Output[Optional[Sequence['outputs.MetricRuleTemplateAlertTemplate']]]:
        """
        The details of alert rules that are generated based on the alert template. See `alert_templates` below.
        """
        return pulumi.get(self, "alert_templates")

    @property
    @pulumi.getter(name="applyMode")
    def apply_mode(self) -> pulumi.Output[Optional[str]]:
        """
        The mode in which the alert template is applied. Valid values:
        - `GROUP_INSTANCE_FIRST`: The metrics in the application group take precedence.
        - `ALARM_TEMPLATE_FIRST `: The metrics specified in the alert template take precedence.
        """
        return pulumi.get(self, "apply_mode")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the alert template.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableEndTime")
    def enable_end_time(self) -> pulumi.Output[Optional[str]]:
        """
        The end of the time period during which the alert rule is effective. Valid values: `00` to `23`. The value `00` indicates 00:59 and the value `23` indicates 23:59.
        """
        return pulumi.get(self, "enable_end_time")

    @property
    @pulumi.getter(name="enableStartTime")
    def enable_start_time(self) -> pulumi.Output[Optional[str]]:
        """
        The beginning of the time period during which the alert rule is effective. Valid values: `00` to `23`. The value `00` indicates 00:00 and the value `23` indicates 23:00.
        """
        return pulumi.get(self, "enable_start_time")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the application group.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="metricRuleTemplateName")
    def metric_rule_template_name(self) -> pulumi.Output[str]:
        """
        The name of the alert template.
        """
        return pulumi.get(self, "metric_rule_template_name")

    @property
    @pulumi.getter(name="notifyLevel")
    def notify_level(self) -> pulumi.Output[Optional[str]]:
        """
        The alert notification method. Valid values:
        """
        return pulumi.get(self, "notify_level")

    @property
    @pulumi.getter(name="restVersion")
    def rest_version(self) -> pulumi.Output[str]:
        """
        The version of the alert template.
        """
        return pulumi.get(self, "rest_version")

    @property
    @pulumi.getter(name="silenceTime")
    def silence_time(self) -> pulumi.Output[Optional[int]]:
        """
        The mute period during which notifications are not repeatedly sent for an alert. Unit: seconds. Default value: `86400`. Valid values: `0` to `86400`.
        """
        return pulumi.get(self, "silence_time")

    @property
    @pulumi.getter
    def webhook(self) -> pulumi.Output[Optional[str]]:
        """
        The callback URL to which a POST request is sent when an alert is triggered based on the alert rule.
        """
        return pulumi.get(self, "webhook")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ProjectArgs', 'Project']

@pulumi.input_type
class ProjectArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[str],
                 service_role: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Project resource.
        :param pulumi.Input[str] project: The name of Project.
        :param pulumi.Input[str] service_role: The service role authorized to the Intelligent Media Management service to access other cloud resources. Default value: `AliyunIMMDefaultRole`. You can also create authorization  roles through the `ram.Role`.
        """
        pulumi.set(__self__, "project", project)
        if service_role is not None:
            pulumi.set(__self__, "service_role", service_role)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The name of Project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="serviceRole")
    def service_role(self) -> Optional[pulumi.Input[str]]:
        """
        The service role authorized to the Intelligent Media Management service to access other cloud resources. Default value: `AliyunIMMDefaultRole`. You can also create authorization  roles through the `ram.Role`.
        """
        return pulumi.get(self, "service_role")

    @service_role.setter
    def service_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_role", value)


@pulumi.input_type
class _ProjectState:
    def __init__(__self__, *,
                 project: Optional[pulumi.Input[str]] = None,
                 service_role: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Project resources.
        :param pulumi.Input[str] project: The name of Project.
        :param pulumi.Input[str] service_role: The service role authorized to the Intelligent Media Management service to access other cloud resources. Default value: `AliyunIMMDefaultRole`. You can also create authorization  roles through the `ram.Role`.
        """
        if project is not None:
            pulumi.set(__self__, "project", project)
        if service_role is not None:
            pulumi.set(__self__, "service_role", service_role)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The name of Project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="serviceRole")
    def service_role(self) -> Optional[pulumi.Input[str]]:
        """
        The service role authorized to the Intelligent Media Management service to access other cloud resources. Default value: `AliyunIMMDefaultRole`. You can also create authorization  roles through the `ram.Role`.
        """
        return pulumi.get(self, "service_role")

    @service_role.setter
    def service_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_role", value)


class Project(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 service_role: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Intelligent Media Management Project resource.

        For information about Intelligent Media Management Project and how to use it, see [What is Project](https://www.alibabacloud.com/help/en/network-intelligence-service/latest/user-overview).

        > **NOTE:** Available since v1.134.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tfexample"
        role = alicloud.ram.Role("role",
            name=name,
            document=\"\"\"  {
            "Statement": [
              {
                "Action": "sts:AssumeRole",
                "Effect": "Allow",
                "Principal": {
                  "Service": [
                    "imm.aliyuncs.com"
                  ]
                }
              }
            ],
            "Version": "1"
          }
        \"\"\",
            description="this is a role test.",
            force=True)
        example = alicloud.imm.Project("example",
            project=name,
            service_role=role.name)
        ```

        ## Import

        Intelligent Media Management Project can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:imm/project:Project example <project>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] project: The name of Project.
        :param pulumi.Input[str] service_role: The service role authorized to the Intelligent Media Management service to access other cloud resources. Default value: `AliyunIMMDefaultRole`. You can also create authorization  roles through the `ram.Role`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Intelligent Media Management Project resource.

        For information about Intelligent Media Management Project and how to use it, see [What is Project](https://www.alibabacloud.com/help/en/network-intelligence-service/latest/user-overview).

        > **NOTE:** Available since v1.134.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tfexample"
        role = alicloud.ram.Role("role",
            name=name,
            document=\"\"\"  {
            "Statement": [
              {
                "Action": "sts:AssumeRole",
                "Effect": "Allow",
                "Principal": {
                  "Service": [
                    "imm.aliyuncs.com"
                  ]
                }
              }
            ],
            "Version": "1"
          }
        \"\"\",
            description="this is a role test.",
            force=True)
        example = alicloud.imm.Project("example",
            project=name,
            service_role=role.name)
        ```

        ## Import

        Intelligent Media Management Project can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:imm/project:Project example <project>
        ```

        :param str resource_name: The name of the resource.
        :param ProjectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 service_role: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectArgs.__new__(ProjectArgs)

            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["service_role"] = service_role
        super(Project, __self__).__init__(
            'alicloud:imm/project:Project',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            project: Optional[pulumi.Input[str]] = None,
            service_role: Optional[pulumi.Input[str]] = None) -> 'Project':
        """
        Get an existing Project resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] project: The name of Project.
        :param pulumi.Input[str] service_role: The service role authorized to the Intelligent Media Management service to access other cloud resources. Default value: `AliyunIMMDefaultRole`. You can also create authorization  roles through the `ram.Role`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectState.__new__(_ProjectState)

        __props__.__dict__["project"] = project
        __props__.__dict__["service_role"] = service_role
        return Project(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The name of Project.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="serviceRole")
    def service_role(self) -> pulumi.Output[str]:
        """
        The service role authorized to the Intelligent Media Management service to access other cloud resources. Default value: `AliyunIMMDefaultRole`. You can also create authorization  roles through the `ram.Role`.
        """
        return pulumi.get(self, "service_role")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['VpcEndpointServiceUserArgs', 'VpcEndpointServiceUser']

@pulumi.input_type
class VpcEndpointServiceUserArgs:
    def __init__(__self__, *,
                 service_id: pulumi.Input[str],
                 user_id: pulumi.Input[str],
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 user_arn: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a VpcEndpointServiceUser resource.
        :param pulumi.Input[str] service_id: The endpoint service ID.
        :param pulumi.Input[str] user_id: The ID of the Alibaba Cloud account in the whitelist of the endpoint service.
        :param pulumi.Input[bool] dry_run: Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        :param pulumi.Input[str] user_arn: The whitelist in the format of ARN.
        """
        pulumi.set(__self__, "service_id", service_id)
        pulumi.set(__self__, "user_id", user_id)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if user_arn is not None:
            pulumi.set(__self__, "user_arn", user_arn)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> pulumi.Input[str]:
        """
        The endpoint service ID.
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "service_id", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[str]:
        """
        The ID of the Alibaba Cloud account in the whitelist of the endpoint service.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "user_id", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="userArn")
    def user_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The whitelist in the format of ARN.
        """
        return pulumi.get(self, "user_arn")

    @user_arn.setter
    def user_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_arn", value)


@pulumi.input_type
class _VpcEndpointServiceUserState:
    def __init__(__self__, *,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 service_id: Optional[pulumi.Input[str]] = None,
                 user_arn: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering VpcEndpointServiceUser resources.
        :param pulumi.Input[bool] dry_run: Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        :param pulumi.Input[str] service_id: The endpoint service ID.
        :param pulumi.Input[str] user_arn: The whitelist in the format of ARN.
        :param pulumi.Input[str] user_id: The ID of the Alibaba Cloud account in the whitelist of the endpoint service.
        """
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if service_id is not None:
            pulumi.set(__self__, "service_id", service_id)
        if user_arn is not None:
            pulumi.set(__self__, "user_arn", user_arn)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[pulumi.Input[str]]:
        """
        The endpoint service ID.
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_id", value)

    @property
    @pulumi.getter(name="userArn")
    def user_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The whitelist in the format of ARN.
        """
        return pulumi.get(self, "user_arn")

    @user_arn.setter
    def user_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_arn", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Alibaba Cloud account in the whitelist of the endpoint service.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_id", value)


class VpcEndpointServiceUser(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 service_id: Optional[pulumi.Input[str]] = None,
                 user_arn: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Private Link Vpc Endpoint Service User resource.

        Endpoint service user whitelist.

        For information about Private Link Vpc Endpoint Service User and how to use it, see [What is Vpc Endpoint Service User](https://www.alibabacloud.com/help/en/privatelink/latest/api-privatelink-2020-04-15-addusertovpcendpointservice).

        > **NOTE:** Available since v1.110.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tfexampleuser"
        example = alicloud.privatelink.VpcEndpointService("example",
            service_description=name,
            connect_bandwidth=103,
            auto_accept_connection=False)
        example_user = alicloud.ram.User("example",
            name=name,
            display_name="user_display_name",
            mobile="86-18688888888",
            email="hello.uuu@aaa.com",
            comments="yoyoyo")
        example_vpc_endpoint_service_user = alicloud.privatelink.VpcEndpointServiceUser("example",
            service_id=example.id,
            user_id=example_user.id)
        ```

        ## Import

        Private Link Vpc Endpoint Service User can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:privatelink/vpcEndpointServiceUser:VpcEndpointServiceUser example <service_id>:<user_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] dry_run: Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        :param pulumi.Input[str] service_id: The endpoint service ID.
        :param pulumi.Input[str] user_arn: The whitelist in the format of ARN.
        :param pulumi.Input[str] user_id: The ID of the Alibaba Cloud account in the whitelist of the endpoint service.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VpcEndpointServiceUserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Private Link Vpc Endpoint Service User resource.

        Endpoint service user whitelist.

        For information about Private Link Vpc Endpoint Service User and how to use it, see [What is Vpc Endpoint Service User](https://www.alibabacloud.com/help/en/privatelink/latest/api-privatelink-2020-04-15-addusertovpcendpointservice).

        > **NOTE:** Available since v1.110.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tfexampleuser"
        example = alicloud.privatelink.VpcEndpointService("example",
            service_description=name,
            connect_bandwidth=103,
            auto_accept_connection=False)
        example_user = alicloud.ram.User("example",
            name=name,
            display_name="user_display_name",
            mobile="86-18688888888",
            email="hello.uuu@aaa.com",
            comments="yoyoyo")
        example_vpc_endpoint_service_user = alicloud.privatelink.VpcEndpointServiceUser("example",
            service_id=example.id,
            user_id=example_user.id)
        ```

        ## Import

        Private Link Vpc Endpoint Service User can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:privatelink/vpcEndpointServiceUser:VpcEndpointServiceUser example <service_id>:<user_id>
        ```

        :param str resource_name: The name of the resource.
        :param VpcEndpointServiceUserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VpcEndpointServiceUserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 service_id: Optional[pulumi.Input[str]] = None,
                 user_arn: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VpcEndpointServiceUserArgs.__new__(VpcEndpointServiceUserArgs)

            __props__.__dict__["dry_run"] = dry_run
            if service_id is None and not opts.urn:
                raise TypeError("Missing required property 'service_id'")
            __props__.__dict__["service_id"] = service_id
            __props__.__dict__["user_arn"] = user_arn
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
        super(VpcEndpointServiceUser, __self__).__init__(
            'alicloud:privatelink/vpcEndpointServiceUser:VpcEndpointServiceUser',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            dry_run: Optional[pulumi.Input[bool]] = None,
            service_id: Optional[pulumi.Input[str]] = None,
            user_arn: Optional[pulumi.Input[str]] = None,
            user_id: Optional[pulumi.Input[str]] = None) -> 'VpcEndpointServiceUser':
        """
        Get an existing VpcEndpointServiceUser resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] dry_run: Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        :param pulumi.Input[str] service_id: The endpoint service ID.
        :param pulumi.Input[str] user_arn: The whitelist in the format of ARN.
        :param pulumi.Input[str] user_id: The ID of the Alibaba Cloud account in the whitelist of the endpoint service.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VpcEndpointServiceUserState.__new__(_VpcEndpointServiceUserState)

        __props__.__dict__["dry_run"] = dry_run
        __props__.__dict__["service_id"] = service_id
        __props__.__dict__["user_arn"] = user_arn
        __props__.__dict__["user_id"] = user_id
        return VpcEndpointServiceUser(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        """
        return pulumi.get(self, "dry_run")

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> pulumi.Output[str]:
        """
        The endpoint service ID.
        """
        return pulumi.get(self, "service_id")

    @property
    @pulumi.getter(name="userArn")
    def user_arn(self) -> pulumi.Output[Optional[str]]:
        """
        The whitelist in the format of ARN.
        """
        return pulumi.get(self, "user_arn")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[str]:
        """
        The ID of the Alibaba Cloud account in the whitelist of the endpoint service.
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GatewaySlbList',
    'GetClustersClusterResult',
    'GetClustersClusterInstanceModelResult',
    'GetEngineNamespacesNamespaceResult',
    'GetGatewaysGatewayResult',
    'GetGatewaysGatewaySlbListResult',
    'GetNacosConfigsConfigResult',
    'GetZnodesZnodeResult',
]

@pulumi.output_type
class GatewaySlbList(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "associateId":
            suggest = "associate_id"
        elif key == "gatewaySlbMode":
            suggest = "gateway_slb_mode"
        elif key == "gatewaySlbStatus":
            suggest = "gateway_slb_status"
        elif key == "gmtCreate":
            suggest = "gmt_create"
        elif key == "slbId":
            suggest = "slb_id"
        elif key == "slbIp":
            suggest = "slb_ip"
        elif key == "slbPort":
            suggest = "slb_port"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GatewaySlbList. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GatewaySlbList.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GatewaySlbList.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 associate_id: Optional[str] = None,
                 gateway_slb_mode: Optional[str] = None,
                 gateway_slb_status: Optional[str] = None,
                 gmt_create: Optional[str] = None,
                 slb_id: Optional[str] = None,
                 slb_ip: Optional[str] = None,
                 slb_port: Optional[str] = None,
                 type: Optional[str] = None):
        """
        :param str associate_id: The associate id.
        :param str gateway_slb_mode: The Mode of the gateway slb.
        :param str gateway_slb_status: The Status of the gateway slb.
        :param str gmt_create: The creation time of the gateway slb.
        :param str slb_id: The ID of the gateway slb.
        :param str slb_ip: The ip of the gateway slb.
        :param str slb_port: The port of the gateway slb.
        :param str type: The type of the gateway slb.
        """
        if associate_id is not None:
            pulumi.set(__self__, "associate_id", associate_id)
        if gateway_slb_mode is not None:
            pulumi.set(__self__, "gateway_slb_mode", gateway_slb_mode)
        if gateway_slb_status is not None:
            pulumi.set(__self__, "gateway_slb_status", gateway_slb_status)
        if gmt_create is not None:
            pulumi.set(__self__, "gmt_create", gmt_create)
        if slb_id is not None:
            pulumi.set(__self__, "slb_id", slb_id)
        if slb_ip is not None:
            pulumi.set(__self__, "slb_ip", slb_ip)
        if slb_port is not None:
            pulumi.set(__self__, "slb_port", slb_port)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="associateId")
    def associate_id(self) -> Optional[str]:
        """
        The associate id.
        """
        return pulumi.get(self, "associate_id")

    @property
    @pulumi.getter(name="gatewaySlbMode")
    def gateway_slb_mode(self) -> Optional[str]:
        """
        The Mode of the gateway slb.
        """
        return pulumi.get(self, "gateway_slb_mode")

    @property
    @pulumi.getter(name="gatewaySlbStatus")
    def gateway_slb_status(self) -> Optional[str]:
        """
        The Status of the gateway slb.
        """
        return pulumi.get(self, "gateway_slb_status")

    @property
    @pulumi.getter(name="gmtCreate")
    def gmt_create(self) -> Optional[str]:
        """
        The creation time of the gateway slb.
        """
        return pulumi.get(self, "gmt_create")

    @property
    @pulumi.getter(name="slbId")
    def slb_id(self) -> Optional[str]:
        """
        The ID of the gateway slb.
        """
        return pulumi.get(self, "slb_id")

    @property
    @pulumi.getter(name="slbIp")
    def slb_ip(self) -> Optional[str]:
        """
        The ip of the gateway slb.
        """
        return pulumi.get(self, "slb_ip")

    @property
    @pulumi.getter(name="slbPort")
    def slb_port(self) -> Optional[str]:
        """
        The port of the gateway slb.
        """
        return pulumi.get(self, "slb_port")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        """
        The type of the gateway slb.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetClustersClusterResult(dict):
    def __init__(__self__, *,
                 acl_id: str,
                 app_version: str,
                 cluster_id: str,
                 cluster_name: str,
                 cluster_type: str,
                 cpu: int,
                 health_status: str,
                 id: str,
                 init_cost_time: int,
                 instance_count: int,
                 instance_id: str,
                 instance_models: Sequence['outputs.GetClustersClusterInstanceModelResult'],
                 internet_address: str,
                 internet_domain: str,
                 internet_port: str,
                 intranet_address: str,
                 intranet_domain: str,
                 intranet_port: str,
                 memory_capacity: int,
                 pay_info: str,
                 pub_network_flow: str,
                 status: str):
        """
        :param str acl_id: The id of acl.
        :param str app_version: The version of app.
        :param str cluster_id: ID of the MSE Cluster.
        :param str cluster_name: ID of the OOS Executions.
        :param str cluster_type: The type of MSE Cluster.
        :param int cpu: The num of cpu.
        :param str health_status: The health status of the instance.
        :param str id: ID of the MSE Cluster.
        :param int init_cost_time: Time-consuming to create.
        :param int instance_count: The count of instance.
        :param str instance_id: ID of the MSE Cluster.
        :param Sequence['GetClustersClusterInstanceModelArgs'] instance_models: The list of instance nodes.
        :param str internet_address: The address of public network.
        :param str internet_domain: The domain of public network.
        :param str internet_port: The port of public network.
        :param str intranet_address: The address of private network.
        :param str intranet_domain: The domain of private network.
        :param str intranet_port: The port of private network.
        :param int memory_capacity: The memory size.
        :param str pay_info: The type of payment.
        :param str pub_network_flow: The public network bandwidth.
        :param str status: The status of MSE Cluster. Valid: `DESTROY_FAILED`, `DESTROY_ING`, `DESTROY_SUCCESS`, `INIT_FAILED`, `INIT_ING`, `INIT_SUCCESS`, `INIT_TIME_OUT`, `RESTART_FAILED`, `RESTART_ING`, `RESTART_SUCCESS`, `SCALE_FAILED`, `SCALE_ING`, `SCALE_SUCCESS`
        """
        pulumi.set(__self__, "acl_id", acl_id)
        pulumi.set(__self__, "app_version", app_version)
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "cluster_name", cluster_name)
        pulumi.set(__self__, "cluster_type", cluster_type)
        pulumi.set(__self__, "cpu", cpu)
        pulumi.set(__self__, "health_status", health_status)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "init_cost_time", init_cost_time)
        pulumi.set(__self__, "instance_count", instance_count)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "instance_models", instance_models)
        pulumi.set(__self__, "internet_address", internet_address)
        pulumi.set(__self__, "internet_domain", internet_domain)
        pulumi.set(__self__, "internet_port", internet_port)
        pulumi.set(__self__, "intranet_address", intranet_address)
        pulumi.set(__self__, "intranet_domain", intranet_domain)
        pulumi.set(__self__, "intranet_port", intranet_port)
        pulumi.set(__self__, "memory_capacity", memory_capacity)
        pulumi.set(__self__, "pay_info", pay_info)
        pulumi.set(__self__, "pub_network_flow", pub_network_flow)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="aclId")
    def acl_id(self) -> str:
        """
        The id of acl.
        """
        return pulumi.get(self, "acl_id")

    @property
    @pulumi.getter(name="appVersion")
    def app_version(self) -> str:
        """
        The version of app.
        """
        return pulumi.get(self, "app_version")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> str:
        """
        ID of the MSE Cluster.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> str:
        """
        ID of the OOS Executions.
        """
        return pulumi.get(self, "cluster_name")

    @property
    @pulumi.getter(name="clusterType")
    def cluster_type(self) -> str:
        """
        The type of MSE Cluster.
        """
        return pulumi.get(self, "cluster_type")

    @property
    @pulumi.getter
    def cpu(self) -> int:
        """
        The num of cpu.
        """
        return pulumi.get(self, "cpu")

    @property
    @pulumi.getter(name="healthStatus")
    def health_status(self) -> str:
        """
        The health status of the instance.
        """
        return pulumi.get(self, "health_status")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        ID of the MSE Cluster.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="initCostTime")
    def init_cost_time(self) -> int:
        """
        Time-consuming to create.
        """
        return pulumi.get(self, "init_cost_time")

    @property
    @pulumi.getter(name="instanceCount")
    def instance_count(self) -> int:
        """
        The count of instance.
        """
        return pulumi.get(self, "instance_count")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        ID of the MSE Cluster.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceModels")
    def instance_models(self) -> Sequence['outputs.GetClustersClusterInstanceModelResult']:
        """
        The list of instance nodes.
        """
        return pulumi.get(self, "instance_models")

    @property
    @pulumi.getter(name="internetAddress")
    def internet_address(self) -> str:
        """
        The address of public network.
        """
        return pulumi.get(self, "internet_address")

    @property
    @pulumi.getter(name="internetDomain")
    def internet_domain(self) -> str:
        """
        The domain of public network.
        """
        return pulumi.get(self, "internet_domain")

    @property
    @pulumi.getter(name="internetPort")
    def internet_port(self) -> str:
        """
        The port of public network.
        """
        return pulumi.get(self, "internet_port")

    @property
    @pulumi.getter(name="intranetAddress")
    def intranet_address(self) -> str:
        """
        The address of private network.
        """
        return pulumi.get(self, "intranet_address")

    @property
    @pulumi.getter(name="intranetDomain")
    def intranet_domain(self) -> str:
        """
        The domain of private network.
        """
        return pulumi.get(self, "intranet_domain")

    @property
    @pulumi.getter(name="intranetPort")
    def intranet_port(self) -> str:
        """
        The port of private network.
        """
        return pulumi.get(self, "intranet_port")

    @property
    @pulumi.getter(name="memoryCapacity")
    def memory_capacity(self) -> int:
        """
        The memory size.
        """
        return pulumi.get(self, "memory_capacity")

    @property
    @pulumi.getter(name="payInfo")
    def pay_info(self) -> str:
        """
        The type of payment.
        """
        return pulumi.get(self, "pay_info")

    @property
    @pulumi.getter(name="pubNetworkFlow")
    def pub_network_flow(self) -> str:
        """
        The public network bandwidth.
        """
        return pulumi.get(self, "pub_network_flow")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of MSE Cluster. Valid: `DESTROY_FAILED`, `DESTROY_ING`, `DESTROY_SUCCESS`, `INIT_FAILED`, `INIT_ING`, `INIT_SUCCESS`, `INIT_TIME_OUT`, `RESTART_FAILED`, `RESTART_ING`, `RESTART_SUCCESS`, `SCALE_FAILED`, `SCALE_ING`, `SCALE_SUCCESS`
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetClustersClusterInstanceModelResult(dict):
    def __init__(__self__, *,
                 health_status: str,
                 instance_type: str,
                 internet_ip: str,
                 ip: str,
                 pod_name: str,
                 role: str,
                 single_tunnel_vip: str,
                 vip: str):
        """
        :param str health_status: The health status of the instance.
        :param str instance_type: (Deprecated from version 1.232.0)
        :param str internet_ip: The public IP address.
        :param str ip: The IP address of the instance.
        :param str pod_name: The name of the pod.
        :param str role: The role.
        :param str single_tunnel_vip: The single-thread IP address.
        :param str vip: (Deprecated from version 1.232.0)
        """
        pulumi.set(__self__, "health_status", health_status)
        pulumi.set(__self__, "instance_type", instance_type)
        pulumi.set(__self__, "internet_ip", internet_ip)
        pulumi.set(__self__, "ip", ip)
        pulumi.set(__self__, "pod_name", pod_name)
        pulumi.set(__self__, "role", role)
        pulumi.set(__self__, "single_tunnel_vip", single_tunnel_vip)
        pulumi.set(__self__, "vip", vip)

    @property
    @pulumi.getter(name="healthStatus")
    def health_status(self) -> str:
        """
        The health status of the instance.
        """
        return pulumi.get(self, "health_status")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> str:
        """
        (Deprecated from version 1.232.0)
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="internetIp")
    def internet_ip(self) -> str:
        """
        The public IP address.
        """
        return pulumi.get(self, "internet_ip")

    @property
    @pulumi.getter
    def ip(self) -> str:
        """
        The IP address of the instance.
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="podName")
    def pod_name(self) -> str:
        """
        The name of the pod.
        """
        return pulumi.get(self, "pod_name")

    @property
    @pulumi.getter
    def role(self) -> str:
        """
        The role.
        """
        return pulumi.get(self, "role")

    @property
    @pulumi.getter(name="singleTunnelVip")
    def single_tunnel_vip(self) -> str:
        """
        The single-thread IP address.
        """
        return pulumi.get(self, "single_tunnel_vip")

    @property
    @pulumi.getter
    def vip(self) -> str:
        """
        (Deprecated from version 1.232.0)
        """
        return pulumi.get(self, "vip")


@pulumi.output_type
class GetEngineNamespacesNamespaceResult(dict):
    def __init__(__self__, *,
                 config_count: int,
                 id: str,
                 namespace_desc: str,
                 namespace_id: str,
                 namespace_show_name: str,
                 quota: int,
                 service_count: str,
                 type: int):
        """
        :param int config_count: The Number of Configuration of the Namespace.
        :param str id: The ID of the Engine Namespace. It is formatted to `<instance_id>:<namespace_id>`.
        :param str namespace_desc: The description of the Namespace.
        :param str namespace_id: The id of Namespace.
        :param str namespace_show_name: The name of the Namespace.
        :param int quota: The Quota of the Namespace.
        :param str service_count: The number of active services.
        :param int type: The type of the Namespace, the value is as follows:
               - '0': Global Configuration.
               - '1': default namespace.
               - '2': Custom Namespace.
        """
        pulumi.set(__self__, "config_count", config_count)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "namespace_desc", namespace_desc)
        pulumi.set(__self__, "namespace_id", namespace_id)
        pulumi.set(__self__, "namespace_show_name", namespace_show_name)
        pulumi.set(__self__, "quota", quota)
        pulumi.set(__self__, "service_count", service_count)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="configCount")
    def config_count(self) -> int:
        """
        The Number of Configuration of the Namespace.
        """
        return pulumi.get(self, "config_count")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Engine Namespace. It is formatted to `<instance_id>:<namespace_id>`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="namespaceDesc")
    def namespace_desc(self) -> str:
        """
        The description of the Namespace.
        """
        return pulumi.get(self, "namespace_desc")

    @property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> str:
        """
        The id of Namespace.
        """
        return pulumi.get(self, "namespace_id")

    @property
    @pulumi.getter(name="namespaceShowName")
    def namespace_show_name(self) -> str:
        """
        The name of the Namespace.
        """
        return pulumi.get(self, "namespace_show_name")

    @property
    @pulumi.getter
    def quota(self) -> int:
        """
        The Quota of the Namespace.
        """
        return pulumi.get(self, "quota")

    @property
    @pulumi.getter(name="serviceCount")
    def service_count(self) -> str:
        """
        The number of active services.
        """
        return pulumi.get(self, "service_count")

    @property
    @pulumi.getter
    def type(self) -> int:
        """
        The type of the Namespace, the value is as follows:
        - '0': Global Configuration.
        - '1': default namespace.
        - '2': Custom Namespace.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetGatewaysGatewayResult(dict):
    def __init__(__self__, *,
                 backup_vswitch_id: str,
                 gateway_name: str,
                 gateway_unique_id: str,
                 id: str,
                 payment_type: str,
                 replica: str,
                 slb_lists: Sequence['outputs.GetGatewaysGatewaySlbListResult'],
                 spec: str,
                 status: str,
                 vpc_id: str,
                 vswitch_id: str):
        """
        :param str backup_vswitch_id: The backup vswitch id.
        :param str gateway_name: The name of the Gateway.
        :param str gateway_unique_id: Gateway unique identification.
        :param str id: The ID of the Gateway.
        :param str payment_type: The payment type of the resource.
        :param str replica: Number of Gateway Nodes.
        :param Sequence['GetGatewaysGatewaySlbListArgs'] slb_lists: A list of gateway Slb.
        :param str spec: Gateway Node Specifications.
        :param str status: The status of the gateway.
        :param str vpc_id: The ID of the vpc.
        :param str vswitch_id: The ID of the vswitch.
        """
        pulumi.set(__self__, "backup_vswitch_id", backup_vswitch_id)
        pulumi.set(__self__, "gateway_name", gateway_name)
        pulumi.set(__self__, "gateway_unique_id", gateway_unique_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "replica", replica)
        pulumi.set(__self__, "slb_lists", slb_lists)
        pulumi.set(__self__, "spec", spec)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="backupVswitchId")
    def backup_vswitch_id(self) -> str:
        """
        The backup vswitch id.
        """
        return pulumi.get(self, "backup_vswitch_id")

    @property
    @pulumi.getter(name="gatewayName")
    def gateway_name(self) -> str:
        """
        The name of the Gateway.
        """
        return pulumi.get(self, "gateway_name")

    @property
    @pulumi.getter(name="gatewayUniqueId")
    def gateway_unique_id(self) -> str:
        """
        Gateway unique identification.
        """
        return pulumi.get(self, "gateway_unique_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Gateway.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> str:
        """
        The payment type of the resource.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter
    def replica(self) -> str:
        """
        Number of Gateway Nodes.
        """
        return pulumi.get(self, "replica")

    @property
    @pulumi.getter(name="slbLists")
    def slb_lists(self) -> Sequence['outputs.GetGatewaysGatewaySlbListResult']:
        """
        A list of gateway Slb.
        """
        return pulumi.get(self, "slb_lists")

    @property
    @pulumi.getter
    def spec(self) -> str:
        """
        Gateway Node Specifications.
        """
        return pulumi.get(self, "spec")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the gateway.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> str:
        """
        The ID of the vpc.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> str:
        """
        The ID of the vswitch.
        """
        return pulumi.get(self, "vswitch_id")


@pulumi.output_type
class GetGatewaysGatewaySlbListResult(dict):
    def __init__(__self__, *,
                 associate_id: str,
                 gateway_slb_mode: str,
                 gateway_slb_status: str,
                 gmt_create: str,
                 slb_id: str,
                 slb_ip: str,
                 slb_port: str,
                 type: str):
        """
        :param str associate_id: The associate id.
        :param str gateway_slb_mode: The Mode of the gateway slb.
        :param str gateway_slb_status: The Status of the gateway slb.
        :param str gmt_create: The creation time of the gateway slb.
        :param str slb_id: The ID of the gateway slb.
        :param str slb_ip: The ip of the gateway slb.
        :param str slb_port: The port of the gateway slb.
        :param str type: The type of the gateway slb.
        """
        pulumi.set(__self__, "associate_id", associate_id)
        pulumi.set(__self__, "gateway_slb_mode", gateway_slb_mode)
        pulumi.set(__self__, "gateway_slb_status", gateway_slb_status)
        pulumi.set(__self__, "gmt_create", gmt_create)
        pulumi.set(__self__, "slb_id", slb_id)
        pulumi.set(__self__, "slb_ip", slb_ip)
        pulumi.set(__self__, "slb_port", slb_port)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="associateId")
    def associate_id(self) -> str:
        """
        The associate id.
        """
        return pulumi.get(self, "associate_id")

    @property
    @pulumi.getter(name="gatewaySlbMode")
    def gateway_slb_mode(self) -> str:
        """
        The Mode of the gateway slb.
        """
        return pulumi.get(self, "gateway_slb_mode")

    @property
    @pulumi.getter(name="gatewaySlbStatus")
    def gateway_slb_status(self) -> str:
        """
        The Status of the gateway slb.
        """
        return pulumi.get(self, "gateway_slb_status")

    @property
    @pulumi.getter(name="gmtCreate")
    def gmt_create(self) -> str:
        """
        The creation time of the gateway slb.
        """
        return pulumi.get(self, "gmt_create")

    @property
    @pulumi.getter(name="slbId")
    def slb_id(self) -> str:
        """
        The ID of the gateway slb.
        """
        return pulumi.get(self, "slb_id")

    @property
    @pulumi.getter(name="slbIp")
    def slb_ip(self) -> str:
        """
        The ip of the gateway slb.
        """
        return pulumi.get(self, "slb_ip")

    @property
    @pulumi.getter(name="slbPort")
    def slb_port(self) -> str:
        """
        The port of the gateway slb.
        """
        return pulumi.get(self, "slb_port")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The type of the gateway slb.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetNacosConfigsConfigResult(dict):
    def __init__(__self__, *,
                 app_name: str,
                 beta_ips: str,
                 content: str,
                 data_id: str,
                 desc: str,
                 encrypted_data_key: str,
                 group: str,
                 id: str,
                 md5: str,
                 tags: str,
                 type: str):
        """
        :param str app_name: The name of the application.
        :param str beta_ips: The list of IP addresses where the beta release of the configuration is performed.
        :param str content: The content of the configuration.
        :param str data_id: The ID of the data.
        :param str desc: The description of the configuration.
        :param str encrypted_data_key: The encryption key.
        :param str group: The ID of the group.
        :param str id: The ID of the Nacos Config. It is formatted to `<instance_id>:<namespace_id>:<data_id>:<group>`.
        :param str md5: The message digest of the configuration.
        :param str tags: The tags of the configuration.
        :param str type: The format of the configuration. Supported formats include TEXT, JSON, and XML.
        """
        pulumi.set(__self__, "app_name", app_name)
        pulumi.set(__self__, "beta_ips", beta_ips)
        pulumi.set(__self__, "content", content)
        pulumi.set(__self__, "data_id", data_id)
        pulumi.set(__self__, "desc", desc)
        pulumi.set(__self__, "encrypted_data_key", encrypted_data_key)
        pulumi.set(__self__, "group", group)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "md5", md5)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="appName")
    def app_name(self) -> str:
        """
        The name of the application.
        """
        return pulumi.get(self, "app_name")

    @property
    @pulumi.getter(name="betaIps")
    def beta_ips(self) -> str:
        """
        The list of IP addresses where the beta release of the configuration is performed.
        """
        return pulumi.get(self, "beta_ips")

    @property
    @pulumi.getter
    def content(self) -> str:
        """
        The content of the configuration.
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter(name="dataId")
    def data_id(self) -> str:
        """
        The ID of the data.
        """
        return pulumi.get(self, "data_id")

    @property
    @pulumi.getter
    def desc(self) -> str:
        """
        The description of the configuration.
        """
        return pulumi.get(self, "desc")

    @property
    @pulumi.getter(name="encryptedDataKey")
    def encrypted_data_key(self) -> str:
        """
        The encryption key.
        """
        return pulumi.get(self, "encrypted_data_key")

    @property
    @pulumi.getter
    def group(self) -> str:
        """
        The ID of the group.
        """
        return pulumi.get(self, "group")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Nacos Config. It is formatted to `<instance_id>:<namespace_id>:<data_id>:<group>`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def md5(self) -> str:
        """
        The message digest of the configuration.
        """
        return pulumi.get(self, "md5")

    @property
    @pulumi.getter
    def tags(self) -> str:
        """
        The tags of the configuration.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The format of the configuration. Supported formats include TEXT, JSON, and XML.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetZnodesZnodeResult(dict):
    def __init__(__self__, *,
                 cluster_id: str,
                 data: str,
                 dir: bool,
                 id: str,
                 path: str,
                 znode_name: str):
        """
        :param str cluster_id: The ID of the Cluster.
        :param str data: The Node data.
        :param bool dir: Node list information, the value is as follows:
        :param str id: The ID of the Znode. The value formats as `<cluster_id>:<path>`.
        :param str path: The Node path.
        :param str znode_name: The Node name.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "data", data)
        pulumi.set(__self__, "dir", dir)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "path", path)
        pulumi.set(__self__, "znode_name", znode_name)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> str:
        """
        The ID of the Cluster.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def data(self) -> str:
        """
        The Node data.
        """
        return pulumi.get(self, "data")

    @property
    @pulumi.getter
    def dir(self) -> bool:
        """
        Node list information, the value is as follows:
        """
        return pulumi.get(self, "dir")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Znode. The value formats as `<cluster_id>:<path>`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def path(self) -> str:
        """
        The Node path.
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter(name="znodeName")
    def znode_name(self) -> str:
        """
        The Node name.
        """
        return pulumi.get(self, "znode_name")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AScriptArgs', 'AScript']

@pulumi.input_type
class AScriptArgs:
    def __init__(__self__, *,
                 ascript_name: pulumi.Input[str],
                 enabled: pulumi.Input[bool],
                 listener_id: pulumi.Input[str],
                 position: pulumi.Input[str],
                 script_content: pulumi.Input[str],
                 ext_attribute_enabled: Optional[pulumi.Input[bool]] = None,
                 ext_attributes: Optional[pulumi.Input[Sequence[pulumi.Input['AScriptExtAttributeArgs']]]] = None):
        """
        The set of arguments for constructing a AScript resource.
        :param pulumi.Input[str] ascript_name: The name of AScript.
        :param pulumi.Input[bool] enabled: Whether scripts are enabled.
        :param pulumi.Input[str] listener_id: Listener ID of script attribution
        :param pulumi.Input[str] position: Execution location of AScript.
        :param pulumi.Input[str] script_content: The content of AScript.
        :param pulumi.Input[bool] ext_attribute_enabled: Whether extension parameters are enabled.
        :param pulumi.Input[Sequence[pulumi.Input['AScriptExtAttributeArgs']]] ext_attributes: Extended attribute list. See `ext_attributes` below for details.
        """
        pulumi.set(__self__, "ascript_name", ascript_name)
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "listener_id", listener_id)
        pulumi.set(__self__, "position", position)
        pulumi.set(__self__, "script_content", script_content)
        if ext_attribute_enabled is not None:
            pulumi.set(__self__, "ext_attribute_enabled", ext_attribute_enabled)
        if ext_attributes is not None:
            pulumi.set(__self__, "ext_attributes", ext_attributes)

    @property
    @pulumi.getter(name="ascriptName")
    def ascript_name(self) -> pulumi.Input[str]:
        """
        The name of AScript.
        """
        return pulumi.get(self, "ascript_name")

    @ascript_name.setter
    def ascript_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "ascript_name", value)

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[bool]:
        """
        Whether scripts are enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[bool]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> pulumi.Input[str]:
        """
        Listener ID of script attribution
        """
        return pulumi.get(self, "listener_id")

    @listener_id.setter
    def listener_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "listener_id", value)

    @property
    @pulumi.getter
    def position(self) -> pulumi.Input[str]:
        """
        Execution location of AScript.
        """
        return pulumi.get(self, "position")

    @position.setter
    def position(self, value: pulumi.Input[str]):
        pulumi.set(self, "position", value)

    @property
    @pulumi.getter(name="scriptContent")
    def script_content(self) -> pulumi.Input[str]:
        """
        The content of AScript.
        """
        return pulumi.get(self, "script_content")

    @script_content.setter
    def script_content(self, value: pulumi.Input[str]):
        pulumi.set(self, "script_content", value)

    @property
    @pulumi.getter(name="extAttributeEnabled")
    def ext_attribute_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether extension parameters are enabled.
        """
        return pulumi.get(self, "ext_attribute_enabled")

    @ext_attribute_enabled.setter
    def ext_attribute_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ext_attribute_enabled", value)

    @property
    @pulumi.getter(name="extAttributes")
    def ext_attributes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AScriptExtAttributeArgs']]]]:
        """
        Extended attribute list. See `ext_attributes` below for details.
        """
        return pulumi.get(self, "ext_attributes")

    @ext_attributes.setter
    def ext_attributes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AScriptExtAttributeArgs']]]]):
        pulumi.set(self, "ext_attributes", value)


@pulumi.input_type
class _AScriptState:
    def __init__(__self__, *,
                 ascript_name: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 ext_attribute_enabled: Optional[pulumi.Input[bool]] = None,
                 ext_attributes: Optional[pulumi.Input[Sequence[pulumi.Input['AScriptExtAttributeArgs']]]] = None,
                 listener_id: Optional[pulumi.Input[str]] = None,
                 load_balancer_id: Optional[pulumi.Input[str]] = None,
                 position: Optional[pulumi.Input[str]] = None,
                 script_content: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AScript resources.
        :param pulumi.Input[str] ascript_name: The name of AScript.
        :param pulumi.Input[bool] enabled: Whether scripts are enabled.
        :param pulumi.Input[bool] ext_attribute_enabled: Whether extension parameters are enabled.
        :param pulumi.Input[Sequence[pulumi.Input['AScriptExtAttributeArgs']]] ext_attributes: Extended attribute list. See `ext_attributes` below for details.
        :param pulumi.Input[str] listener_id: Listener ID of script attribution
        :param pulumi.Input[str] load_balancer_id: The ID of load balancer instance.
        :param pulumi.Input[str] position: Execution location of AScript.
        :param pulumi.Input[str] script_content: The content of AScript.
        :param pulumi.Input[str] status: The status of AScript.
        """
        if ascript_name is not None:
            pulumi.set(__self__, "ascript_name", ascript_name)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if ext_attribute_enabled is not None:
            pulumi.set(__self__, "ext_attribute_enabled", ext_attribute_enabled)
        if ext_attributes is not None:
            pulumi.set(__self__, "ext_attributes", ext_attributes)
        if listener_id is not None:
            pulumi.set(__self__, "listener_id", listener_id)
        if load_balancer_id is not None:
            pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        if position is not None:
            pulumi.set(__self__, "position", position)
        if script_content is not None:
            pulumi.set(__self__, "script_content", script_content)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="ascriptName")
    def ascript_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of AScript.
        """
        return pulumi.get(self, "ascript_name")

    @ascript_name.setter
    def ascript_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ascript_name", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether scripts are enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="extAttributeEnabled")
    def ext_attribute_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether extension parameters are enabled.
        """
        return pulumi.get(self, "ext_attribute_enabled")

    @ext_attribute_enabled.setter
    def ext_attribute_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ext_attribute_enabled", value)

    @property
    @pulumi.getter(name="extAttributes")
    def ext_attributes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AScriptExtAttributeArgs']]]]:
        """
        Extended attribute list. See `ext_attributes` below for details.
        """
        return pulumi.get(self, "ext_attributes")

    @ext_attributes.setter
    def ext_attributes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AScriptExtAttributeArgs']]]]):
        pulumi.set(self, "ext_attributes", value)

    @property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> Optional[pulumi.Input[str]]:
        """
        Listener ID of script attribution
        """
        return pulumi.get(self, "listener_id")

    @listener_id.setter
    def listener_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "listener_id", value)

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of load balancer instance.
        """
        return pulumi.get(self, "load_balancer_id")

    @load_balancer_id.setter
    def load_balancer_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "load_balancer_id", value)

    @property
    @pulumi.getter
    def position(self) -> Optional[pulumi.Input[str]]:
        """
        Execution location of AScript.
        """
        return pulumi.get(self, "position")

    @position.setter
    def position(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "position", value)

    @property
    @pulumi.getter(name="scriptContent")
    def script_content(self) -> Optional[pulumi.Input[str]]:
        """
        The content of AScript.
        """
        return pulumi.get(self, "script_content")

    @script_content.setter
    def script_content(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "script_content", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of AScript.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class AScript(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ascript_name: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 ext_attribute_enabled: Optional[pulumi.Input[bool]] = None,
                 ext_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AScriptExtAttributeArgs', 'AScriptExtAttributeArgsDict']]]]] = None,
                 listener_id: Optional[pulumi.Input[str]] = None,
                 position: Optional[pulumi.Input[str]] = None,
                 script_content: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Alb Ascript resource.

        For information about Alb Ascript and how to use it, see [What is AScript](https://www.alibabacloud.com/help/en/slb/application-load-balancer/developer-reference/api-alb-2020-06-16-createascripts).

        > **NOTE:** Available since v1.195.0.

        ## Import

        Alb AScript can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:alb/aScript:AScript example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] ascript_name: The name of AScript.
        :param pulumi.Input[bool] enabled: Whether scripts are enabled.
        :param pulumi.Input[bool] ext_attribute_enabled: Whether extension parameters are enabled.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AScriptExtAttributeArgs', 'AScriptExtAttributeArgsDict']]]] ext_attributes: Extended attribute list. See `ext_attributes` below for details.
        :param pulumi.Input[str] listener_id: Listener ID of script attribution
        :param pulumi.Input[str] position: Execution location of AScript.
        :param pulumi.Input[str] script_content: The content of AScript.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AScriptArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Alb Ascript resource.

        For information about Alb Ascript and how to use it, see [What is AScript](https://www.alibabacloud.com/help/en/slb/application-load-balancer/developer-reference/api-alb-2020-06-16-createascripts).

        > **NOTE:** Available since v1.195.0.

        ## Import

        Alb AScript can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:alb/aScript:AScript example <id>
        ```

        :param str resource_name: The name of the resource.
        :param AScriptArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AScriptArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ascript_name: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 ext_attribute_enabled: Optional[pulumi.Input[bool]] = None,
                 ext_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AScriptExtAttributeArgs', 'AScriptExtAttributeArgsDict']]]]] = None,
                 listener_id: Optional[pulumi.Input[str]] = None,
                 position: Optional[pulumi.Input[str]] = None,
                 script_content: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AScriptArgs.__new__(AScriptArgs)

            if ascript_name is None and not opts.urn:
                raise TypeError("Missing required property 'ascript_name'")
            __props__.__dict__["ascript_name"] = ascript_name
            if enabled is None and not opts.urn:
                raise TypeError("Missing required property 'enabled'")
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["ext_attribute_enabled"] = ext_attribute_enabled
            __props__.__dict__["ext_attributes"] = ext_attributes
            if listener_id is None and not opts.urn:
                raise TypeError("Missing required property 'listener_id'")
            __props__.__dict__["listener_id"] = listener_id
            if position is None and not opts.urn:
                raise TypeError("Missing required property 'position'")
            __props__.__dict__["position"] = position
            if script_content is None and not opts.urn:
                raise TypeError("Missing required property 'script_content'")
            __props__.__dict__["script_content"] = script_content
            __props__.__dict__["load_balancer_id"] = None
            __props__.__dict__["status"] = None
        super(AScript, __self__).__init__(
            'alicloud:alb/aScript:AScript',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ascript_name: Optional[pulumi.Input[str]] = None,
            enabled: Optional[pulumi.Input[bool]] = None,
            ext_attribute_enabled: Optional[pulumi.Input[bool]] = None,
            ext_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AScriptExtAttributeArgs', 'AScriptExtAttributeArgsDict']]]]] = None,
            listener_id: Optional[pulumi.Input[str]] = None,
            load_balancer_id: Optional[pulumi.Input[str]] = None,
            position: Optional[pulumi.Input[str]] = None,
            script_content: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'AScript':
        """
        Get an existing AScript resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] ascript_name: The name of AScript.
        :param pulumi.Input[bool] enabled: Whether scripts are enabled.
        :param pulumi.Input[bool] ext_attribute_enabled: Whether extension parameters are enabled.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AScriptExtAttributeArgs', 'AScriptExtAttributeArgsDict']]]] ext_attributes: Extended attribute list. See `ext_attributes` below for details.
        :param pulumi.Input[str] listener_id: Listener ID of script attribution
        :param pulumi.Input[str] load_balancer_id: The ID of load balancer instance.
        :param pulumi.Input[str] position: Execution location of AScript.
        :param pulumi.Input[str] script_content: The content of AScript.
        :param pulumi.Input[str] status: The status of AScript.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AScriptState.__new__(_AScriptState)

        __props__.__dict__["ascript_name"] = ascript_name
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["ext_attribute_enabled"] = ext_attribute_enabled
        __props__.__dict__["ext_attributes"] = ext_attributes
        __props__.__dict__["listener_id"] = listener_id
        __props__.__dict__["load_balancer_id"] = load_balancer_id
        __props__.__dict__["position"] = position
        __props__.__dict__["script_content"] = script_content
        __props__.__dict__["status"] = status
        return AScript(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="ascriptName")
    def ascript_name(self) -> pulumi.Output[str]:
        """
        The name of AScript.
        """
        return pulumi.get(self, "ascript_name")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[bool]:
        """
        Whether scripts are enabled.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="extAttributeEnabled")
    def ext_attribute_enabled(self) -> pulumi.Output[bool]:
        """
        Whether extension parameters are enabled.
        """
        return pulumi.get(self, "ext_attribute_enabled")

    @property
    @pulumi.getter(name="extAttributes")
    def ext_attributes(self) -> pulumi.Output[Sequence['outputs.AScriptExtAttribute']]:
        """
        Extended attribute list. See `ext_attributes` below for details.
        """
        return pulumi.get(self, "ext_attributes")

    @property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> pulumi.Output[str]:
        """
        Listener ID of script attribution
        """
        return pulumi.get(self, "listener_id")

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> pulumi.Output[str]:
        """
        The ID of load balancer instance.
        """
        return pulumi.get(self, "load_balancer_id")

    @property
    @pulumi.getter
    def position(self) -> pulumi.Output[str]:
        """
        Execution location of AScript.
        """
        return pulumi.get(self, "position")

    @property
    @pulumi.getter(name="scriptContent")
    def script_content(self) -> pulumi.Output[str]:
        """
        The content of AScript.
        """
        return pulumi.get(self, "script_content")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of AScript.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .alias import *
from .application_access_point import *
from .ciphertext import *
from .client_key import *
from .get_aliases import *
from .get_ciphertext import *
from .get_key_versions import *
from .get_keys import *
from .get_plaintext import *
from .get_secret_versions import *
from .get_secrets import *
from .get_service import *
from .instance import *
from .key import *
from .key_version import *
from .network_rule import *
from .policy import *
from .secret import *
from ._inputs import *
from . import outputs
